==> corestuff-2.7.0.tar.gz: corestuff-v2.7.0/corestuff.h <==
/*
    *
    * This file is a part of CoreStuff.
    * An activity viewer for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/


#ifndef CORESTUFF_H
#define CORESTUFF_H

#include <QWidget>
#include <QPushButton>
#include <QFileSystemWatcher>

#include <cprime/settingsmanage.h>

class pageactivites;
class pagehome;
class pagepins;
class pagereminders;
class pagesessions;
class pagetasks;

namespace Ui {
class corestuff;
}

class corestuff : public QWidget
{
    Q_OBJECT

public:
    explicit corestuff(QWidget *parent = nullptr);
    ~corestuff();

    void reload( const QString &path );

protected:
    void closeEvent(QCloseEvent *event);
    void paintEvent(QPaintEvent *pEvent);

private slots:
    void on_home_clicked();
    void on_tasks_clicked();
    void on_activites_clicked();
    void on_reminders_clicked();
    void on_session_clicked();
    void on_pins_clicked();

    void on_clearActivites_clicked();
    void on_editSessoion_clicked();
    void on_deleteSession_clicked();
    void on_addSession_clicked();
    void on_menu_clicked();

    void handleMessages( const QString );

private:
    Ui::corestuff       *ui;
    QFileSystemWatcher  *fswStart;
    int                  currentPage = 0;
    bool                 touch, showRecent,showTasks, desktop;
    QImage               bgImage;

    pageactivites *pActivities = nullptr;
    pagehome      *pHome = nullptr;
    pagepins      *pPins = nullptr;
    pagereminders *pReminders = nullptr;
    pagesessions  *pSessions = nullptr;
    pagetasks     *pTasks = nullptr;

    void pageClick( QPushButton *btn, int i, QString windowTitle );
    void loadSettings();
    void startSetup();
};

#endif // CORESTUFF_H

==> corestuff-2.9.0.tar.gz: corestuff-v2.9.0/corestuff.h <==
/*
    *
    * This file is a part of CoreStuff.
    * An activity viewer for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/


#ifndef CORESTUFF_H
#define CORESTUFF_H

#include <QWidget>
#include <QToolButton>
#include <QFileSystemWatcher>

#include <cprime/settingsmanage.h>

class pageactivites;
class pagehome;
class pagepins;
class pagereminders;
class pagesessions;
class pageapps;
class pagetasks;

namespace Ui {
    class corestuff;
}

class corestuff : public QWidget
{
    Q_OBJECT

public:
    explicit corestuff(QWidget *parent = nullptr);
    ~corestuff();

    void reload( const QString &path );

    void showTasksPage();
    void showDesktopT();
    void VolumeUp();
    void VolumeDown();
    void TakeCoreshot();
protected:
    void closeEvent(QCloseEvent *event);
    void paintEvent(QPaintEvent *pEvent);

private slots:
    void on_home_clicked();
    void on_tasks_clicked();
    void on_activites_clicked();
    void on_session_clicked();
    void on_pins_clicked();
    void on_menu_clicked();
    void on_apps_clicked();

    void on_power_clicked();
    void on_clearActivites_clicked();
    void on_editSessoion_clicked();
    void on_deleteSession_clicked();
    void on_addSession_clicked();

    void handleMessages( const QString );
    void previousPage();
    void nextPage();

private:
    Ui::corestuff       *ui;
    QFileSystemWatcher  *fswStart;
    int                  currentPage = 0;
    bool                 showActivities, desktop, touch;
    QPixmap m_bgpix;
    QSize                toolBarIconSize;
    QImage               bgImage;
    int wallpaperPos;
    int pixOffsetX = 0;
    int pixOffsetY = 0;

    pageactivites *pActivities = nullptr;
    pagehome      *pHome = nullptr;
    pagepins      *pPins = nullptr;
    pagereminders *pReminders = nullptr;
    pagesessions  *pSessions = nullptr;
    pageapps      *pApps = nullptr;
    pagetasks     *pTasks = nullptr;

    void pageClick( QToolButton *btn, int i, QString windowTitle );
    void loadSettings();
    void startSetup();
    void shortcuts();

    void updateBGPix();
    void resizeWindow();

Q_SIGNALS:
    void activateDock();
};

#endif // CORESTUFF_H
